"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import delphix.api.gateway
from delphix.api.gateway.api.sources_api import SourcesApi  # noqa: E501


class TestSourcesApi(unittest.TestCase):
    """SourcesApi unit test stubs"""

    def setUp(self):
        self.api = SourcesApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_source_tags(self):
        """Test case for create_source_tags

        Create tags for a Source.  # noqa: E501
        """
        pass

    def test_delete_source_tags(self):
        """Test case for delete_source_tags

        Delete tags for a Source.  # noqa: E501
        """
        pass

    def test_get_source_by_id(self):
        """Test case for get_source_by_id

        Get a source by ID.  # noqa: E501
        """
        pass

    def test_get_source_compatible_repo(self):
        """Test case for get_source_compatible_repo

        Returns a list of repositories that match the specified source.  # noqa: E501
        """
        pass

    def test_get_source_tags(self):
        """Test case for get_source_tags

        Get tags for a Source.  # noqa: E501
        """
        pass

    def test_get_sources(self):
        """Test case for get_sources

        List all sources.  # noqa: E501
        """
        pass

    def test_search_sources(self):
        """Test case for search_sources

        Search for Sources.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



"""
    Delphix DCT API

    Delphix DCT API  # noqa: E501

    The version of the OpenAPI document: 3.8.0
    Contact: support@delphix.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import delphix.api.gateway
from delphix.api.gateway.model.base_d_source_link_source_parameters import BaseDSourceLinkSourceParameters
from delphix.api.gateway.model.mssqld_source_link_source_parameters_all_of import MSSQLDSourceLinkSourceParametersAllOf
from delphix.api.gateway.model.source_operation import SourceOperation
from delphix.api.gateway.model.tag import Tag
globals()['BaseDSourceLinkSourceParameters'] = BaseDSourceLinkSourceParameters
globals()['MSSQLDSourceLinkSourceParametersAllOf'] = MSSQLDSourceLinkSourceParametersAllOf
globals()['SourceOperation'] = SourceOperation
globals()['Tag'] = Tag
from delphix.api.gateway.model.mssqld_source_link_source_parameters import MSSQLDSourceLinkSourceParameters


class TestMSSQLDSourceLinkSourceParameters(unittest.TestCase):
    """MSSQLDSourceLinkSourceParameters unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testMSSQLDSourceLinkSourceParameters(self):
        """Test MSSQLDSourceLinkSourceParameters"""
        # FIXME: construct object with mandatory attributes with example values
        # model = MSSQLDSourceLinkSourceParameters()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
